==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Draw/Image/ts/Image_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>Image</name>
    <message>
        <location filename="../Image.js" line="+125"/>
        <source>Files</source>
        <translatorcomment>--google--
Todos os Arquivos de Imagem (%1)
Todos os Ficheiros (*.*)
Todos os Ficheiros (*)</translatorcomment>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>All Image Files (%1)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Todos os Arquivos de Imagem (%1)</translatorcomment>
        <translation>Todos os Arquivos de imagem (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translatorcomment>--exact match--
--file: pt.po--
Todos os Ficheiros (*.*)
Todos os Ficheiros (*)</translatorcomment>
        <translation>Todos os arquivos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Import Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Importar bitmap</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Indique a dimensão da linha de posicionamento ou insira o ângulo:
Indique a dimensão da linha de posicionamento ou insira o ângulo
Indique a posição [ângulo/comprimento]</translatorcomment>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../ImageInit.js" line="+2"/>
        <source>Insert Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Inserir bitmap</translation>
    </message>
    <message>
        <location filename="../Image.ui" line="+17"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Largura:
&amp;Largura do Papel:</translatorcomment>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Mantenha proporções</translatorcomment>
        <translation>Mantenha proporções</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Altura:
&amp;Altura do Papel:</translatorcomment>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Draw/Image/ts/Image_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Image</name>
    <message>
        <location filename="../Image.js" line="+132"/>
        <source>Files</source>
        <translatorcomment>--google--
Todos os Arquivos de Imagem (%1)
Todos os Ficheiros (*.*)
Todos os Ficheiros (*)</translatorcomment>
        <translation>Arquivos</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>All Image Files (%1)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Todos os Arquivos de Imagem (%1)</translatorcomment>
        <translation>Todos os Arquivos de Imagem (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translatorcomment>--exact match--
--file: pt.po--
Todos os Ficheiros (*.*)
Todos os Ficheiros (*)</translatorcomment>
        <translation>Todos os Arquivos</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Import Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Importar um Bitmap</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Indique a dimensão da linha de posicionamento ou insira o ângulo:
Indique a dimensão da linha de posicionamento ou insira o ângulo
Indique a posição [ângulo/comprimento]</translatorcomment>
        <translation>Posição</translation>
    </message>
    <message>
        <location filename="../ImageInit.js" line="+2"/>
        <source>Insert Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Insira um Bitmap</translation>
    </message>
    <message>
        <location filename="../Image.ui" line="+17"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Largura:
&amp;Largura do Papel:</translatorcomment>
        <translation>Largura:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Mantenha proporções</translatorcomment>
        <translation>Mantenha as proporções</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Altura:
&amp;Altura do Papel:</translatorcomment>
        <translation>Altura:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo:</translation>
    </message>
</context>
</TS>
